.. _lab:contribution:

How to contribute
=================

RHEIA is under active development. In case of issues or missing functionalities,
we recommend to open an issue on the `Github Issue Tracker <https://github.com/rheia-framework/RHEIA/issues>`_.
Alternatively, contact us directly (rheia.framework@gmail.com).
Finally, you can start a `push request <https://github.com/rheia-framework/RHEIA/pulls>`_.

RHEIA generally follows the `PEP 8 - Style Guide for Python Code <https://www.python.org/dev/peps/pep-0008/>`_.
We aim for a maximum code line length of 79 characters.
